aboutsummaryrefslogtreecommitdiff
path: root/scumm/sound.cpp
diff options
context:
space:
mode:
authorTravis Howell2004-08-29 11:27:16 +0000
committerTravis Howell2004-08-29 11:27:16 +0000
commitcbf5a60bab5770e7b199014f509720a248d12d5a (patch)
tree30883d2858ce93f475ae654c941399ad633c747b /scumm/sound.cpp
parent3540014e4590941f39c5975ce072f489f467edd7 (diff)
downloadscummvm-rg350-cbf5a60bab5770e7b199014f509720a248d12d5a.tar.gz
scummvm-rg350-cbf5a60bab5770e7b199014f509720a248d12d5a.tar.bz2
scummvm-rg350-cbf5a60bab5770e7b199014f509720a248d12d5a.zip
Add a few akos codes
Give unknown akos codes better names Rename actor variable Remove hack (Use multi-version flag instead) Another sound correction for HE games. svn-id: r14827
Diffstat (limited to 'scumm/sound.cpp')
-rw-r--r--scumm/sound.cpp8
1 files changed, 3 insertions, 5 deletions
diff --git a/scumm/sound.cpp b/scumm/sound.cpp
index f71866019f..5284db1084 100644
--- a/scumm/sound.cpp
+++ b/scumm/sound.cpp
@@ -180,7 +180,7 @@ void Sound::playSound(int soundID, int offset) {
musicFile.seek(+40, SEEK_CUR);
if (musicFile.readUint32LE() == MKID('SGEN')) {
- // TODO Work out skpi calcution
+ // TODO Work out skip calcution
//skip = (soundID - 8001) * 21;
musicFile.seek(+skip, SEEK_CUR);
@@ -191,8 +191,8 @@ void Sound::playSound(int soundID, int offset) {
// Rewind
musicFile.seek(-44, SEEK_CUR);
- // Skip header junk
- musicFile.seek(+20, SEEK_CUR);
+ // Skip SGHD header (16)
+ musicFile.seek(+16, SEEK_CUR);
// Skip to correct music header
if (soundID >= 8000)
@@ -201,8 +201,6 @@ void Sound::playSound(int soundID, int offset) {
skip = (soundID - 4001) * 25;
musicFile.seek(+skip, SEEK_CUR);
- // Skip to offsets
- musicFile.seek(+21, SEEK_CUR);
}